@@ -12,17 +12,17 @@ fn run() {
     let lexer_rules = nixel::lexer::lexer_rules();
     let grammar = nixel::grammar::grammar();
 
-    let nixpkgs_dir = "/data/nixpkgs";
+    let nixpkgs_dir = "tests/nixpkgs";
     let cases_dir = "tests/cases";
 
     for path_input in &nix_files(nixpkgs_dir)[0..1000] {
         let case = path_input.strip_prefix(nixpkgs_dir).unwrap()[1..]
             .replace('/', "-");
 
+        dbg!(&case);
+
         std::fs::create_dir_all(format!("{cases_dir}/{case}")).unwrap();
 
-        // let path_lexemes = format!("{cases_dir}/{case}/lexemes");
-        // let path_parse_trees = format!("{cases_dir}/{case}/parse_trees");
         let path_asts = format!("{cases_dir}/{case}/asts");
 
         let input = std::fs::read_to_string(&path_input)
@@ -31,37 +31,7 @@ fn run() {
             .to_string();
 
         let lexemes = santiago::lexer::lex(&lexer_rules, &input).unwrap();
-        // let lexemes_str: String = lexemes
-        //     .iter()
-        //     .map(|lexeme| lexeme.to_string())
-        //     .collect::<Vec<String>>()
-        //     .join("\n");
-
-        // #[cfg(not(tarpaulin))]
-        // if should_update {
-        //     std::fs::File::create(&path_lexemes)
-        //         .unwrap()
-        //         .write_all(lexemes_str.as_bytes())
-        //         .unwrap();
-        // }
-
         let parse_trees = santiago::parser::parse(&grammar, &lexemes).unwrap();
-        // let parse_trees_str: String = parse_trees
-        //     .iter()
-        //     .map(|parse_tree| format!("---\n{parse_tree}"))
-        //     .collect::<String>()
-        //     .lines()
-        //     .collect::<Vec<&str>>()
-        //     .join("\n");
-
-        // #[cfg(not(tarpaulin))]
-        // if should_update {
-        //     std::fs::File::create(&path_parse_trees)
-        //         .unwrap()
-        //         .write_all(parse_trees_str.as_bytes())
-        //         .unwrap();
-        // }
-
         let ast: Vec<AST> = parse_trees
             .iter()
             .map(|parse_tree| parse_tree.as_abstract_syntax_tree())
@@ -97,14 +67,6 @@ fn run() {
                 .unwrap();
         }
 
-        // assert_eq!(
-        //     lexemes_str,
-        //     std::fs::read_to_string(&path_lexemes).unwrap()
-        // );
-        // assert_eq!(
-        //     parse_trees_str,
-        //     std::fs::read_to_string(&path_parse_trees).unwrap()
-        // );
         assert_eq!(ast_str, std::fs::read_to_string(&path_asts).unwrap());
     }
 }
